==> rktSNS_1.070528.tgz: rktSNS/htdocs/resource/js/option.js <==
// ========================================================================
// - [prefecture.js]
// - package：Prefecture functions
// - author：Yujiro Takahashi
// - modified：
// -      [2006/07/02] created
// - contact：    yujiro@rakuto.net
// -      Copyright (C) 2006 `rakuto.net'. All Rights Reserved.
// - =======================================================================

function addOption(){
	if ($('option').value == ''){
		return ;
	}

	var node = $('options');
    var row  = node.length;
    var option = new Option($('option').value);
    
    option.value = 0;

    node.length = row + 1;
	node.options[row] = option;

	$('option').value = '';
}

function editOption(){
	var node = $('options');
	if (node.selectedIndex < 0){
		return ;
	}

	node.options[node.selectedIndex].text = $('option').value;
	$('option').value = '';
}

function deleteOption(){
	var node = $('options');
	if (node.selectedIndex < 0){
		return ;
	}
	node.options[node.selectedIndex] = null;
	$('option').value = '';
}

function setOption(){
	var node = $('options');
	if (node.selectedIndex < 0){
		return ;
	}
	$('option').value = node.options[node.selectedIndex].text;
}

function setHidden(){
	var node  = $('options');
	var id    = null;
	var value = null;
 	
	for (var row=0; row<node.length; row++){
		id    = document.createElement('input');
		id.setAttribute('type','hidden');
		id.setAttribute('name','com_option['+ row +'][id]');
		id.value = node.options[row].value;

		$('option_value').appendChild(id);

		value = document.createElement('input');
		value.setAttribute('type','hidden');
		value.setAttribute('name','com_option['+ row +'][item]');
		value.value = node.options[row].text;

		$('option_value').appendChild(value);
	}
}

==> rktSNS_1.070830.tgz: rktSNS/htdocs/resource/js/option.js <==
// ========================================================================
// - [prefecture.js]
// - package：Prefecture functions
// - author：Yujiro Takahashi
// - modified：
// -      [2006/07/02] created
// - contact：    yujiro@rakuto.net
// -      Copyright (C) 2006 `rakuto.net'. All Rights Reserved.
// - =======================================================================

function addOption(){
	if ($('option').value == ''){
		return ;
	}

	var node = $('options');
    var row  = node.length;
    var option = new Option($('option').value);
    
    option.value = 0;

    node.length = row + 1;
	node.options[row] = option;

	$('option').value = '';
}

function editOption(){
	var node = $('options');
	if (node.selectedIndex < 0){
		return ;
	}

	node.options[node.selectedIndex].text = $('option').value;
	$('option').value = '';
}

function deleteOption(){
	var node = $('options');
	if (node.selectedIndex < 0){
		return ;
	}
	node.options[node.selectedIndex] = null;
	$('option').value = '';
}

function setOption(){
	var node = $('options');
	if (node.selectedIndex < 0){
		return ;
	}
	$('option').value = node.options[node.selectedIndex].text;
}

function setHidden(){
	var node  = $('options');
	var id    = null;
	var value = null;
 	
	for (var row=0; row<node.length; row++){
		id    = document.createElement('input');
		id.setAttribute('type','hidden');
		id.setAttribute('name','com_option['+ row +'][id]');
		id.value = node.options[row].value;

		$('option_value').appendChild(id);

		value = document.createElement('input');
		value.setAttribute('type','hidden');
		value.setAttribute('name','com_option['+ row +'][item]');
		value.value = node.options[row].text;

		$('option_value').appendChild(value);
	}
}

function addInput(){
	var node  = $('options');
	var count = 0;
	var value = null;
	var br = null;

	for (var row=0; row<node.childNodes.length; row++){
		if (node.childNodes[row].type == 'text'){
			if (node.childNodes[row].value == ''){
				count ++;
			}
		}
	}

	
	if (count <= 1){
		value = document.createElement('input');
		value.setAttribute('type','text');
		value.setAttribute('class','list');
		value.setAttribute('name','com_option['+ row +'][item]');
		value.value = '';
		Event.observe(value, 'focus', function(){addInput();});

		node.appendChild(value);

		br = document.createElement('br');
		node.appendChild(br);
	}
}
